@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ob-swiftui" "0.11.1"
+(define-package "ob-swiftui" "20251023.1031"
   "Org babel functions for SwiftUI evaluation."
   '((emacs      "25.1")
     (swift-mode "8.2.0")
